window.Gleam.initSearch([{"doc":"checkmark","title":"checkmark","content":"# checkmark\n\n[![Package Version](https://img.shields.io/hexpm/v/checkmark)](https://hex.pm/packages/checkmark)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/checkmark/)\n\nCheckmark is a library for checking that gleam code in markdown files\ntype checks, builds, or runs successfully.\n\n## Example\n\n```sh\ngleam add checkmark\n```\n\n```gleam\nimport checkmark\nimport gleam/string\n\npub fn main() {\n  // Checks that a single gleam code block in README.md that starts with &quot;import&quot;\n  // passes type checks, by creating the temporary file `checkmark_tmp.gleam`\n  // Checking in a temporary project is also supported.\n  let assert Ok([Ok(_)]) =\n    checkmark.new()\n    |&gt; checkmark.snippets_in(&quot;README.md&quot;)\n    |&gt; checkmark.filtering(string.starts_with(_, &quot;import&quot;))\n    |&gt; checkmark.check_in_current_package(&quot;checkmark_tmp.gleam&quot;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/checkmark&gt;.\n","url":"index.html"},{"doc":"checkmark","title":"CheckConfig","content":"pub opaque type CheckConfig\n Configuration for checking a markdown file.\n\nSynonyms:\ncheckmark.CheckConfig\ncheckmark CheckConfig","url":"checkmark.html#CheckConfig"},{"doc":"checkmark","title":"CheckError","content":"pub type CheckError {\n  RunFailed(String)\n  CheckFailed(String)\n}\n Indicates a check on an individual snippet failed\nRunFailed(String)\n Running the check failed before we could get the result from `gleam`.\n The string value might currently be a bit cryptic, it should be improved.\n\nCheckFailed(String)\n We were able to run the `gleam` operation, but it failed with the given output.\n\nSynonyms:\ncheckmark.CheckError\ncheckmark CheckError","url":"checkmark.html#CheckError"},{"doc":"checkmark","title":"CheckResult","content":"pub type CheckResult =\n  Result(Nil, CheckError)\n Type alias for a result of checking a single snippet.\n\nSynonyms:\ncheckmark.CheckResult\ncheckmark CheckResult","url":"checkmark.html#CheckResult"},{"doc":"checkmark","title":"Operation","content":"pub type Operation {\n  Check\n  Build\n  Run\n}\n Specifies the `gleam` CLI operation to run on each snippet\nCheck\n Will run `gleam check` on the code\n\nBuild\n Will run `gleam build` on the code\n\nRun\n Will run `gleam run` on the code\n\nSynonyms:\ncheckmark.Operation\ncheckmark Operation","url":"checkmark.html#Operation"},{"doc":"checkmark","title":"check_in_current_package","content":"pub fn check_in_current_package(\n  config: CheckConfig,\n  as_file filename: String,\n) -&gt; Result(List(Result(Nil, CheckError)), String)\n Runs checks in the current package,\n writing into temporary file at `src/{filename}`.\n The result will be `Error` if the whole operation failed (e.g. couldn&#39;t read snippets)\n or `Ok` with a list of results for each snippet found in the file.\nSynonyms:\ncheckmark.check_in_current_package\ncheckmark check_in_current_package","url":"checkmark.html#check_in_current_package"},{"doc":"checkmark","title":"check_in_tmp_package","content":"pub fn check_in_tmp_package(\n  config: CheckConfig,\n  dependencies: List(String),\n) -&gt; Result(List(Result(Nil, CheckError)), String)\n Runs checks in a temporarily set up package,\n installing the given dependencies using `gleam add`.\n The result will be `Error` if the whole operation failed (e.g. couldn&#39;t read snippets)\n or `Ok` with a list of results for each snippet found in the file.\nSynonyms:\ncheckmark.check_in_tmp_package\ncheckmark check_in_tmp_package","url":"checkmark.html#check_in_tmp_package"},{"doc":"checkmark","title":"filtering","content":"pub fn filtering(\n  config: CheckConfig,\n  filter: fn(String) -&gt; Bool,\n) -&gt; CheckConfig\n Filters snippets by their content. E.g. `string.starts_with(_, &quot;import&quot;)`\nSynonyms:\ncheckmark.filtering\ncheckmark filtering","url":"checkmark.html#filtering"},{"doc":"checkmark","title":"new","content":"pub fn new() -&gt; CheckConfig\n Constructs a new check configuration with the defaults of\n running `gleam check` on all snippets in the README.md file.\nSynonyms:\ncheckmark.new\ncheckmark new","url":"checkmark.html#new"},{"doc":"checkmark","title":"snippets_in","content":"pub fn snippets_in(\n  config: CheckConfig,\n  filename: String,\n) -&gt; CheckConfig\n Specifies the markdown file to check (default is README.md)\nSynonyms:\ncheckmark.snippets_in\ncheckmark snippets_in","url":"checkmark.html#snippets_in"},{"doc":"checkmark","title":"using","content":"pub fn using(\n  config: CheckConfig,\n  operation: Operation,\n) -&gt; CheckConfig\n Uses the given operation, default is `Check`\nSynonyms:\ncheckmark.using\ncheckmark using","url":"checkmark.html#using"},{"doc":"checkmark","title":"checkmark","content":"","url":"checkmark.html"}]);